@@ -45,6 +45,7 @@ def fun_control_init(
     horizon=None,
     hyperdict=None,
     infill_criterion="y",
+    log_every_n_steps=50,
     log_level=50,
     lower=None,
     max_time=1,
@@ -54,6 +55,7 @@ def fun_control_init(
     noise=False,
     n_points=1,
     n_samples=None,
+    num_sanity_val_steps=2,
     n_total=None,
     num_workers=0,
     num_nodes=1,
@@ -159,6 +161,8 @@ def fun_control_init(
             For example: `spotriver.hyperdict.river_hyper_dict import RiverHyperDict`
         infill_criterion (str):
             Can be `"y"`, `"s"`, `"ei"` (negative expected improvement), or `"all"`. Default is "y".
+        log_every_n_steps (int):
+            Lightning: How often to log within steps. Default: 50.
         log_level (int):
             log level with the following settings:
             `NOTSET` (`0`),
@@ -183,6 +187,10 @@ def fun_control_init(
             Affects the repeat of the function evaluations.
         n_points (int):
             The number of infill points to be generated by the surrogate in each iteration.
+        num_sanity_val_steps (int):
+                Lightning: Sanity check runs n validation batches before starting the training routine.
+                Set it to -1 to run all batches in all validation dataloaders.
+                Default: 2.
         n_samples (int):
             The number of samples in the dataset. Default is None.
         n_total (int):
@@ -391,6 +399,7 @@ def fun_control_init(
         "hyperdict": hyperdict,
         "infill_criterion": infill_criterion,
         "k_folds": 3,
+        "log_every_n_steps": log_every_n_steps,
         "log_graph": False,
         "log_level": log_level,
         "loss_function": None,
@@ -408,6 +417,7 @@ def fun_control_init(
         "n_samples": n_samples,
         "n_total": n_total,
         "num_nodes": num_nodes,
+        "num_sanity_val_steps": num_sanity_val_steps,
         "num_workers": num_workers,
         "ocba_delta": ocba_delta,
         "oml_grace_period": oml_grace_period,
